==> knative-model-6.1.0-sources.jar: io/fabric8/knative/internal/eventing/pkg/apis/duck/v1/DeliverySpecFluentImpl.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DeliverySpecFluentImpl<A extends DeliverySpecFluent<A>> extends BaseFluent<A> implements DeliverySpecFluent<A>{
  public DeliverySpecFluentImpl() {
  }
  public DeliverySpecFluentImpl(DeliverySpec instance) {
    this.withBackoffDelay(instance.getBackoffDelay()); 
    this.withBackoffPolicy(instance.getBackoffPolicy()); 
    this.withDeadLetterSink(instance.getDeadLetterSink()); 
    this.withRetry(instance.getRetry()); 
    this.withRetryAfterMax(instance.getRetryAfterMax()); 
    this.withTimeout(instance.getTimeout()); 
  }
  private String backoffDelay;
  private String backoffPolicy;
  private DestinationBuilder deadLetterSink;
  private Integer retry;
  private String retryAfterMax;
  private String timeout;
  public String getBackoffDelay() {
    return this.backoffDelay;
  }
  public A withBackoffDelay(String backoffDelay) {
    this.backoffDelay=backoffDelay; return (A) this;
  }
  public Boolean hasBackoffDelay() {
    return this.backoffDelay != null;
  }
  public String getBackoffPolicy() {
    return this.backoffPolicy;
  }
  public A withBackoffPolicy(String backoffPolicy) {
    this.backoffPolicy=backoffPolicy; return (A) this;
  }
  public Boolean hasBackoffPolicy() {
    return this.backoffPolicy != null;
  }
  
  /**
   * This method has been deprecated, please use method buildDeadLetterSink instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getDeadLetterSink() {
    return this.deadLetterSink!=null ?this.deadLetterSink.build():null;
  }
  public Destination buildDeadLetterSink() {
    return this.deadLetterSink!=null ?this.deadLetterSink.build():null;
  }
  public A withDeadLetterSink(Destination deadLetterSink) {
    _visitables.get("deadLetterSink").remove(this.deadLetterSink);
    if (deadLetterSink!=null){ this.deadLetterSink= new DestinationBuilder(deadLetterSink); _visitables.get("deadLetterSink").add(this.deadLetterSink);} else { this.deadLetterSink = null; _visitables.get("deadLetterSink").remove(this.deadLetterSink); } return (A) this;
  }
  public Boolean hasDeadLetterSink() {
    return this.deadLetterSink != null;
  }
  public DeliverySpecFluent.DeadLetterSinkNested<A> withNewDeadLetterSink() {
    return new DeliverySpecFluentImpl.DeadLetterSinkNestedImpl();
  }
  public DeliverySpecFluent.DeadLetterSinkNested<A> withNewDeadLetterSinkLike(Destination item) {
    return new DeliverySpecFluentImpl.DeadLetterSinkNestedImpl(item);
  }
  public DeliverySpecFluent.DeadLetterSinkNested<A> editDeadLetterSink() {
    return withNewDeadLetterSinkLike(getDeadLetterSink());
  }
  public DeliverySpecFluent.DeadLetterSinkNested<A> editOrNewDeadLetterSink() {
    return withNewDeadLetterSinkLike(getDeadLetterSink() != null ? getDeadLetterSink(): new DestinationBuilder().build());
  }
  public DeliverySpecFluent.DeadLetterSinkNested<A> editOrNewDeadLetterSinkLike(Destination item) {
    return withNewDeadLetterSinkLike(getDeadLetterSink() != null ? getDeadLetterSink(): item);
  }
  public Integer getRetry() {
    return this.retry;
  }
  public A withRetry(Integer retry) {
    this.retry=retry; return (A) this;
  }
  public Boolean hasRetry() {
    return this.retry != null;
  }
  public String getRetryAfterMax() {
    return this.retryAfterMax;
  }
  public A withRetryAfterMax(String retryAfterMax) {
    this.retryAfterMax=retryAfterMax; return (A) this;
  }
  public Boolean hasRetryAfterMax() {
    return this.retryAfterMax != null;
  }
  public String getTimeout() {
    return this.timeout;
  }
  public A withTimeout(String timeout) {
    this.timeout=timeout; return (A) this;
  }
  public Boolean hasTimeout() {
    return this.timeout != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DeliverySpecFluentImpl that = (DeliverySpecFluentImpl) o;
    if (backoffDelay != null ? !backoffDelay.equals(that.backoffDelay) :that.backoffDelay != null) return false;
    if (backoffPolicy != null ? !backoffPolicy.equals(that.backoffPolicy) :that.backoffPolicy != null) return false;
    if (deadLetterSink != null ? !deadLetterSink.equals(that.deadLetterSink) :that.deadLetterSink != null) return false;
    if (retry != null ? !retry.equals(that.retry) :that.retry != null) return false;
    if (retryAfterMax != null ? !retryAfterMax.equals(that.retryAfterMax) :that.retryAfterMax != null) return false;
    if (timeout != null ? !timeout.equals(that.timeout) :that.timeout != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(backoffDelay,  backoffPolicy,  deadLetterSink,  retry,  retryAfterMax,  timeout,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (backoffDelay != null) { sb.append("backoffDelay:"); sb.append(backoffDelay + ","); }
    if (backoffPolicy != null) { sb.append("backoffPolicy:"); sb.append(backoffPolicy + ","); }
    if (deadLetterSink != null) { sb.append("deadLetterSink:"); sb.append(deadLetterSink + ","); }
    if (retry != null) { sb.append("retry:"); sb.append(retry + ","); }
    if (retryAfterMax != null) { sb.append("retryAfterMax:"); sb.append(retryAfterMax + ","); }
    if (timeout != null) { sb.append("timeout:"); sb.append(timeout); }
    sb.append("}");
    return sb.toString();
  }
  class DeadLetterSinkNestedImpl<N> extends DestinationFluentImpl<DeliverySpecFluent.DeadLetterSinkNested<N>> implements DeliverySpecFluent.DeadLetterSinkNested<N>,Nested<N>{
    DeadLetterSinkNestedImpl(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    DeadLetterSinkNestedImpl() {
      this.builder = new DestinationBuilder(this);
    }
    DestinationBuilder builder;
    public N and() {
      return (N) DeliverySpecFluentImpl.this.withDeadLetterSink(builder.build());
    }
    public N endDeadLetterSink() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/internal/eventing/pkg/apis/duck/v1/DeliverySpecFluentImpl.java <==
package io.fabric8.knative.internal.eventing.pkg.apis.duck.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluentImpl;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DeliverySpecFluentImpl<A extends DeliverySpecFluent<A>> extends BaseFluent<A> implements DeliverySpecFluent<A>{
  public DeliverySpecFluentImpl() {
  }
  public DeliverySpecFluentImpl(DeliverySpec instance) {
    if (instance != null) {
      this.withBackoffDelay(instance.getBackoffDelay());
      this.withBackoffPolicy(instance.getBackoffPolicy());
      this.withDeadLetterSink(instance.getDeadLetterSink());
      this.withRetry(instance.getRetry());
      this.withRetryAfterMax(instance.getRetryAfterMax());
      this.withTimeout(instance.getTimeout());
    }
  }
  private String backoffDelay;
  private String backoffPolicy;
  private DestinationBuilder deadLetterSink;
  private Integer retry;
  private String retryAfterMax;
  private String timeout;
  public String getBackoffDelay() {
    return this.backoffDelay;
  }
  public A withBackoffDelay(String backoffDelay) {
    this.backoffDelay=backoffDelay; return (A) this;
  }
  public Boolean hasBackoffDelay() {
    return this.backoffDelay != null;
  }
  public String getBackoffPolicy() {
    return this.backoffPolicy;
  }
  public A withBackoffPolicy(String backoffPolicy) {
    this.backoffPolicy=backoffPolicy; return (A) this;
  }
  public Boolean hasBackoffPolicy() {
    return this.backoffPolicy != null;
  }
  
  /**
   * This method has been deprecated, please use method buildDeadLetterSink instead.
   * @return The buildable object.
   */
  @Deprecated
  public Destination getDeadLetterSink() {
    return this.deadLetterSink!=null ?this.deadLetterSink.build():null;
  }
  public Destination buildDeadLetterSink() {
    return this.deadLetterSink!=null ?this.deadLetterSink.build():null;
  }
  public A withDeadLetterSink(Destination deadLetterSink) {
    _visitables.get("deadLetterSink").remove(this.deadLetterSink);
    if (deadLetterSink!=null){ this.deadLetterSink= new DestinationBuilder(deadLetterSink); _visitables.get("deadLetterSink").add(this.deadLetterSink);} else { this.deadLetterSink = null; _visitables.get("deadLetterSink").remove(this.deadLetterSink); } return (A) this;
  }
  public Boolean hasDeadLetterSink() {
    return this.deadLetterSink != null;
  }
  public DeliverySpecFluentImpl.DeadLetterSinkNested<A> withNewDeadLetterSink() {
    return new DeliverySpecFluentImpl.DeadLetterSinkNestedImpl();
  }
  public DeliverySpecFluentImpl.DeadLetterSinkNested<A> withNewDeadLetterSinkLike(Destination item) {
    return new DeliverySpecFluentImpl.DeadLetterSinkNestedImpl(item);
  }
  public DeliverySpecFluentImpl.DeadLetterSinkNested<A> editDeadLetterSink() {
    return withNewDeadLetterSinkLike(getDeadLetterSink());
  }
  public DeliverySpecFluentImpl.DeadLetterSinkNested<A> editOrNewDeadLetterSink() {
    return withNewDeadLetterSinkLike(getDeadLetterSink() != null ? getDeadLetterSink(): new DestinationBuilder().build());
  }
  public DeliverySpecFluentImpl.DeadLetterSinkNested<A> editOrNewDeadLetterSinkLike(Destination item) {
    return withNewDeadLetterSinkLike(getDeadLetterSink() != null ? getDeadLetterSink(): item);
  }
  public Integer getRetry() {
    return this.retry;
  }
  public A withRetry(Integer retry) {
    this.retry=retry; return (A) this;
  }
  public Boolean hasRetry() {
    return this.retry != null;
  }
  public String getRetryAfterMax() {
    return this.retryAfterMax;
  }
  public A withRetryAfterMax(String retryAfterMax) {
    this.retryAfterMax=retryAfterMax; return (A) this;
  }
  public Boolean hasRetryAfterMax() {
    return this.retryAfterMax != null;
  }
  public String getTimeout() {
    return this.timeout;
  }
  public A withTimeout(String timeout) {
    this.timeout=timeout; return (A) this;
  }
  public Boolean hasTimeout() {
    return this.timeout != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeliverySpecFluentImpl that = (DeliverySpecFluentImpl) o;
    if (!java.util.Objects.equals(backoffDelay, that.backoffDelay)) return false;

    if (!java.util.Objects.equals(backoffPolicy, that.backoffPolicy)) return false;

    if (!java.util.Objects.equals(deadLetterSink, that.deadLetterSink)) return false;

    if (!java.util.Objects.equals(retry, that.retry)) return false;

    if (!java.util.Objects.equals(retryAfterMax, that.retryAfterMax)) return false;

    if (!java.util.Objects.equals(timeout, that.timeout)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(backoffDelay,  backoffPolicy,  deadLetterSink,  retry,  retryAfterMax,  timeout,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (backoffDelay != null) { sb.append("backoffDelay:"); sb.append(backoffDelay + ","); }
    if (backoffPolicy != null) { sb.append("backoffPolicy:"); sb.append(backoffPolicy + ","); }
    if (deadLetterSink != null) { sb.append("deadLetterSink:"); sb.append(deadLetterSink + ","); }
    if (retry != null) { sb.append("retry:"); sb.append(retry + ","); }
    if (retryAfterMax != null) { sb.append("retryAfterMax:"); sb.append(retryAfterMax + ","); }
    if (timeout != null) { sb.append("timeout:"); sb.append(timeout); }
    sb.append("}");
    return sb.toString();
  }
  class DeadLetterSinkNestedImpl<N> extends DestinationFluentImpl<DeliverySpecFluentImpl.DeadLetterSinkNested<N>> implements DeliverySpecFluentImpl.DeadLetterSinkNested<N>,Nested<N>{
    DeadLetterSinkNestedImpl(Destination item) {
      this.builder = new DestinationBuilder(this, item);
    }
    DeadLetterSinkNestedImpl() {
      this.builder = new DestinationBuilder(this);
    }
    DestinationBuilder builder;
    public N and() {
      return (N) DeliverySpecFluentImpl.this.withDeadLetterSink(builder.build());
    }
    public N endDeadLetterSink() {
      return and();
    }
    
  }
  
}
